Enum yearly_version::VersionComparator

source ·
#[repr(C, align(8))]
pub enum VersionComparator { Exact = 0, Greater = 1, GreaterEqual = 2, Less = 3, LessEqual = 4, Tilde = 5, Caret = 6, Wildcard = 7, }
SemVer comparison operator: =, >, >=, <, <=, ~, ^, *.

Op::Exact

  • =I.J.K — exactly the version I.J.K
  • =I.J — equivalent to >=I.J.0, <I.(J+1).0
  • =I — equivalent to >=I.0.0, <(I+1).0.0

Op::Wildcard

  • I.J.* — equivalent to =I.J
  • I.* or I.*.* — equivalent to =I

Op::Greater

  • >I.J.K
  • >I.J — equivalent to >=I.(J+1).0
  • >I — equivalent to >=(I+1).0.0

Op::GreaterEq

  • >=I.J.K
  • >=I.J — equivalent to >=I.J.0
  • >=I — equivalent to >=I.0.0

Op::Less

  • <I.J.K
  • <I.J — equivalent to <I.J.0
  • <I — equivalent to <I.0.0

Op::LessEq

  • <=I.J.K
  • <=I.J — equivalent to <I.(J+1).0
  • <=I — equivalent to <(I+1).0.0

Op::Tilde (“patch” updates)

Tilde requirements allow the patch part of the semver version (the third number) to increase.

  • ~I.J.K — equivalent to >=I.J.K, <I.(J+1).0
  • ~I.J — equivalent to =I.J
  • ~I — equivalent to =I

Op::Caret (“compatible” updates)

Caret requirements allow parts that are right of the first nonzero part of the semver version to increase.

  • ^I.J.K (for I>0) — equivalent to >=I.J.K, <(I+1).0.0
  • ^0.J.K (for J>0) — equivalent to >=0.J.K, <0.(J+1).0
  • ^0.0.K — equivalent to =0.0.K
  • ^I.J (for I>0 or J>0) — equivalent to ^I.J.0
  • ^0.0 — equivalent to =0.0
  • ^I — equivalent to =I

Variants



Exact = 0

=YEAR
=YEAR.MAJOR
=YEAR.MAJOR.MINOR
=YEAR.MAJOR.MINOR.PATCH


Greater = 1

>YEAR
>YEAR.MAJOR
>YEAR.MAJOR.MINOR
>YEAR.MAJOR.MINOR.PATCH


GreaterEqual = 2

>=YEAR
>=YEAR.MAJOR
>=YEAR.MAJOR.MINOR
>=YEAR.MAJOR.MINOR.PATCH


Less = 3

<YEAR
<YEAR.MAJOR
<YEAR.MAJOR.MINOR
<YEAR.MAJOR.MINOR.PATCH


LessEqual = 4

<=YEAR
<=YEAR.MAJOR
<=YEAR.MAJOR.MINOR
<=YEAR.MAJOR.MINOR.PATCH


Tilde = 5

~YEAR
~YEAR.MAJOR
~YEAR.MAJOR.MINOR
~YEAR.MAJOR.MINOR.PATCH


Caret = 6

^YEAR
^YEAR.MAJOR
^YEAR.MAJOR.MINOR.*
^YEAR.MAJOR.MINOR.PATCH


Wildcard = 7

*
YEAR.*
YEAR.MAJOR.*
YEAR.MAJOR.MINOR.*

Implementations

source

impl VersionComparator

source

impl VersionComparator

source

pub fn range( &self, year: Option<u32>, major: Option<u32>, minor: Option<u32>, patch: Option<u32> ) -> Option<RangeInclusive<Version>>

source

pub fn upper( &self, year: Option<u32>, major: Option<u32>, minor: Option<u32>, patch: Option<u32> ) -> Version

source

pub fn lower( &self, year: Option<u32>, major: Option<u32>, minor: Option<u32>, patch: Option<u32> ) -> Version